==> snipe-it-6.3.0.zip: snipe-it-6.3.0/resources/lang/tr-TR/admin/locations/table.php <==
<?php

return [
    'about_locations_title'     => 'Lokasyonlar hakkında',
    'about_locations'           => 'Konum bilgileri kullanıcılar, varlıklar ve diğer nesneleri izlemek için kullanılır',
    'assets_rtd'                => 'Varlıklar', // This has NEVER meant Assets Retired. I don't know how it keeps getting reverted.
    'assets_checkedout'         => 'Varlık Atandı',
    'id'                        => 'ID',
    'city'                      => 'Şehir',
    'state'                     => 'Bölge',
    'country'                   => 'Ülke',
    'create'                    => 'Konum Oluştur',
    'update'                    => 'Konum Güncelle',
    'print_assigned'            => 'Atananların Tümünü Yazdır',
    'print_all_assigned'        => 'Atananların Tümünü Yazdır',
    'name'                      => 'Konum Adı',
    'address'                   => 'Adres',
    'address2'                   => 'Adres Satırı 2',
    'zip'                       => 'Posta kodu',
    'locations'                 => 'Konumlar',
    'parent'                    => 'Üst',
    'currency'                  => 'Lokasyon Para Birimi',
    'ldap_ou'                   => 'LDAP arama OU',
    'user_name'                 => 'Kullancı Adı',
    'department'                => 'Bölüm',
    'location'                  => 'Yer',
    'asset_tag'                 => 'Demirbaş Etiketi',
    'asset_name'                => 'Ad',
    'asset_category'            => 'Kategori',
    'asset_manufacturer'        => 'Üretici',
    'asset_model'               => 'Model',
    'asset_serial'              => 'Seri No',
    'asset_location'            => 'Konum',
    'asset_checked_out'         => 'Çıkış Yapıldı',
    'asset_expected_checkin'    => 'Beklenen geri alma tarihi',
    'date'                      => 'Tarih:',
    'phone'                     => 'Location Phone',
    'signed_by_asset_auditor'   => 'İmzalayan (Demirbaş Denetçisi):',
    'signed_by_finance_auditor' => 'İmzalayan (Maliye Denetçisi):',
    'signed_by_location_manager' => 'İmzalayan (Mekan Sorumlusu):',
    'signed_by'                 => 'İmzalayan:',
];

==> snipe-it-7.0.11.zip: snipe-it-7.0.11/resources/lang/tr-TR/admin/locations/table.php <==
<?php

return [
    'about_locations_title'     => 'Lokasyonlar hakkında',
    'about_locations'           => 'Konum bilgileri kullanıcılar, varlıklar ve diğer nesneleri izlemek için kullanılır',
    'assets_rtd'                => 'Varlıklar', // This has NEVER meant Assets Retired. I don't know how it keeps getting reverted.
    'assets_checkedout'         => 'Varlık Atandı',
    'id'                        => 'ID',
    'city'                      => 'Şehir',
    'state'                     => 'Bölge',
    'country'                   => 'Ülke',
    'create'                    => 'Konum Oluştur',
    'update'                    => 'Konum Güncelle',
    'print_assigned'            => 'Atananların Tümünü Yazdır',
    'print_all_assigned'        => 'Atananların Tümünü Yazdır',
    'name'                      => 'Konum Adı',
    'address'                   => 'Adres',
    'address2'                   => 'Adres Satırı 2',
    'zip'                       => 'Posta kodu',
    'locations'                 => 'Konumlar',
    'parent'                    => 'Üst',
    'currency'                  => 'Lokasyon Para Birimi',
    'ldap_ou'                   => 'LDAP arama OU',
    'user_name'                 => 'Kullancı Adı',
    'department'                => 'Bölüm',
    'location'                  => 'Yer',
    'asset_tag'                 => 'Demirbaş Etiketi',
    'asset_name'                => 'Ad',
    'asset_category'            => 'Kategori',
    'asset_manufacturer'        => 'Üretici',
    'asset_model'               => 'Model',
    'asset_serial'              => 'Seri No',
    'asset_location'            => 'Konum',
    'asset_checked_out'         => 'Çıkış Yapıldı',
    'asset_expected_checkin'    => 'Beklenen geri alma tarihi',
    'date'                      => 'Tarih:',
    'phone'                     => 'Konum Telefonu',
    'signed_by_asset_auditor'   => 'İmzalayan (Demirbaş Denetçisi):',
    'signed_by_finance_auditor' => 'İmzalayan (Maliye Denetçisi):',
    'signed_by_location_manager' => 'İmzalayan (Mekan Sorumlusu):',
    'signed_by'                 => 'İmzalayan:',
];
